use anyhow::{Context, Result};
use std::path::PathBuf;

use super::{syntax, ContentType};

#[derive(Debug)]
pub struct Content {
	pub systems: Vec<syntax::system::System>,
	pub ships: Vec<syntax::ship::Ship>,
}

impl Content {
	pub fn new(cv: Vec<(PathBuf, ContentType)>) -> Result<Self> {
		let mut systems = Vec::new();
		let mut ships = Vec::new();

		// These methods check intra-file consistency
		for (p, c) in cv {
			match c {
				ContentType::System(v) => systems.push(
					syntax::system::System::parse(v)
						.with_context(|| format!("Could not parse {}", p.display()))?,
				),

				ContentType::Ship(v) => ships.push(
					syntax::ship::Ship::parse(v)
						.with_context(|| format!("Could not parse {}", p.display()))?,
				),
			}
		}

		return Ok(Self { systems, ships });
	}
}
